Skip to contents

Prints a form-feed character. Whether this clears the display depends on your console.

Usage

clear(...)

Arguments

...

An unused argument.

Value

No return value (called for side effect of printing a form feed character to the console, which visually clears the R terminal). Returns NULL invisibly.

Author

Charles Crabtree charles.crabtree@monash.edu

Examples

clear()
#>