| violinplots | R Documentation |
Returns violin plots for the relationship between two measures for each group/unit.
violinplots(x, y, group, data)
x |
A vector. |
y |
A vector. |
group |
A vector that contains unit/group identifiers. |
data |
A data frame. |
Violin plots for the relationship between two measures for each group/unit.
Charles Crabtree charles.crabtree@monash.edu
a <- runif(1000, min = 0, max = 1)
b <- a + rnorm(1000, mean = 0, sd = 1)
c <- rep(c(1:10), times = 100)
data <- data.frame(a, b, c)
violinplots("a", "b", "c", data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.