bivarplots: Plots the bivariate relationship between two measures for...

View source: R/bivarplots.r

bivarplotsR Documentation

Plots the bivariate relationship between two measures for each group/unit

Description

Returns a plot of the bivariate relationship between two measures for each group/unit.

Usage

bivarplots(x, y, group, data)

Arguments

x

A vector.

y

A vector.

group

A vector.

data

A data frame.

Value

A series of figures that plot the bivariate relationship between two measures for each group/unit.

Author(s)

Charles Crabtree charles.crabtree@monash.edu

Examples

a <- runif(1000, min = 0, max = 1)
b <- a + rnorm(1000, mean = 0, sd = 1)
c <- rep(c(1:10), times = 100)
data <- data.frame(a, b, c)
bivarplots("a", "b", "c", data)

plotrr documentation built on March 27, 2026, 5:06 p.m.