bivarrugplot: Plots the bivariate relationship between two measures and a...

View source: R/bivarrugplot.r

bivarrugplotR Documentation

Plots the bivariate relationship between two measures and a rugplot for each measure

Description

Returns a plot of the bivariate relationship between two measures with a rugplot for each measure.

Usage

bivarrugplot(x, y, data)

Arguments

x

A vector.

y

A vector.

data

A data frame.

Value

A plot of the bivariate relationship between two measures with a rugplot for each measure.

Author(s)

Charles Crabtree charles.crabtree@monash.edu

Examples

a <- runif(1000, min = 0, max = 1)
b <- a + rnorm(1000, mean = 0, sd = 1)
data <- data.frame(a, b)
bivarrugplot("a", "b", data)

plotrr documentation built on March 27, 2026, 5:06 p.m.