clear: (Effectively) clears R terminal

View source: R/clear.r

clearR Documentation

(Effectively) clears R terminal

Description

Effectively clears the R terminal by filling it with whitespace.

Usage

clear(...)

Arguments

...

An unused argument.

Value

No return value (called for side effect of printing a form feed character to the console, which visually clears the R terminal). Returns NULL invisibly.

Author(s)

Charles Crabtree charles.crabtree@monash.edu

Examples

clear()

plotrr documentation built on March 27, 2026, 5:06 p.m.