| clear | R Documentation |
Effectively clears the R terminal by filling it with whitespace.
clear(...)
... |
An unused argument. |
No return value (called for side effect of printing a form feed
character to the console, which visually clears the R terminal). Returns
NULL invisibly.
Charles Crabtree charles.crabtree@monash.edu
clear()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.